@@ -2,22 +2,23 @@ require "English"
 
 require "erb"
 require "optparse"
-require "rd/rdvisitor"
-require "rd/version"
+begin
+  require "rd/rdvisitor"
+  require "rd/version"
+rescue LoadError
+  require 'rubygems'
+  gem 'rdtool'
+  require "rd/rdvisitor"
+  require "rd/version"
+end
 
 require 'rd-visitor-util'
 
-begin
-  require "gettext"
-rescue LoadError
-  require "rubygems"
-  require "gettext"
-end
-begin
-  require "gettext/tools"
-rescue LoadError
-  require "gettext/poparser"
-  GetText::MOFile = MOFile
+require "rubygems"
+require "fast_gettext/po_file"
+
+if Object.const_defined?(:Encoding)
+  Encoding.default_external = Encoding::UTF_8
 end
 
 module RD
@@ -31,6 +32,7 @@ module RD
 
     @@po = nil
     @@name = nil
+    @@target_file_name = nil
     class << self
       def version
         VERSION
@@ -43,6 +45,10 @@ module RD
       def name=(name)
         @@name = name
       end
+
+      def target_file_name=(file_name)
+        @@target_file_name = file_name
+      end
     end
 
     # must-have constants
@@ -294,12 +300,11 @@ module RD
     end
 
     def make_translate_data
-      data = GetText::MOFile.new
       if @@po
-        parser = GetText::PoParser.new
-        parser.parse(File.read(@@po), data)
+        FastGettext::PoFile.to_mo_file(@@po)
+      else
+        FastGettext::MoFile.empty
       end
-      data
     end
 
     def xml_decl
@@ -313,7 +318,7 @@ module RD
     end
 
     def ref_entry_id(filename=nil)
-      filename ||= ARGF.filename
+      filename ||= @@target_file_name
       remove_suffix(File.basename(filename)).downcase
     end
 
@@ -324,7 +329,7 @@ module RD
 
     def tag(name, attributes={}, *contents)
       encoded_attributes = attributes.collect do |key, value|
-        "#{key}=\"#{h(value)}\""
+        "#{key}=\'#{h(value)}\'"
       end.join(" ")
       unless encoded_attributes.empty?
         encoded_attributes = " #{encoded_attributes}"
@@ -438,6 +443,8 @@ module RD
 end
 
 $Visitor_Class = RD::RD2RefEntryVisitor
+# FIXME: Couldn't get target file name by ARGF.filename
+RD::RD2RefEntryVisitor.target_file_name = ARGV.last
 ARGV.options do |opts|
   opts.on("--name=NAME", "The library name") do |name|
     RD::RD2RefEntryVisitor.name = name
