@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2010  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2013  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -103,6 +103,10 @@ cut_setup (void)
         "" LINE_FEED_CODE
         "Application Options:" LINE_FEED_CODE
         "  --version                                         Show version" LINE_FEED_CODE
+        "  --log-level=LEVEL                                 "
+        "Set log level to LEVEL. LEVEL can be combined them with '|': "
+        "(all|default|none|critical|error|warning|message|info|debug|trace) "
+        "(default: critical|error|warning|message)" LINE_FEED_CODE
         "  --mode=[test|analyze|play]                        Set run mode (default: test)" LINE_FEED_CODE
         "  -s, --source-directory=DIRECTORY                  Set directory of source code" LINE_FEED_CODE
         "  -n, --name=TEST_NAME                              Specify tests" LINE_FEED_CODE
@@ -259,8 +263,8 @@ test_help_all (void)
         "  --gtk-name=NAME                                   Program name as used by the window manager" LINE_FEED_CODE
         "  --screen=SCREEN                                   X screen to use" LINE_FEED_CODE
 #  ifdef HAVE_GTK_ENABLE_DEBUG
-        "  --gdk-debug=FLAGS                                 Gdk debugging flags to set" LINE_FEED_CODE
-        "  --gdk-no-debug=FLAGS                              Gdk debugging flags to unset" LINE_FEED_CODE
+        "  --gdk-debug=FLAGS                                 GDK debugging flags to set" LINE_FEED_CODE
+        "  --gdk-no-debug=FLAGS                              GDK debugging flags to unset" LINE_FEED_CODE
 #  endif
 #  ifdef GDK_WINDOWING_X11
         "  --sync                                            Make X calls synchronous" LINE_FEED_CODE
@@ -281,6 +285,10 @@ test_help_all (void)
 #endif
         "Application Options:" LINE_FEED_CODE
         "  --version                                         Show version" LINE_FEED_CODE
+        "  --log-level=LEVEL                                 "
+        "Set log level to LEVEL. LEVEL can be combined them with '|': "
+        "(all|default|none|critical|error|warning|message|info|debug|trace) "
+        "(default: critical|error|warning|message)" LINE_FEED_CODE
         "  --mode=[test|analyze|play]                        Set run mode (default: test)" LINE_FEED_CODE
         "  -s, --source-directory=DIRECTORY                  Set directory of source code" LINE_FEED_CODE
         "  -n, --name=TEST_NAME                              Specify tests" LINE_FEED_CODE
