@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2009  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2009-2012  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -49,6 +49,10 @@ void test_equal_object_null(void);
 void test_equal_object_custom(void);
 void test_equal_pid(void);
 void test_not_equal_pid(void);
+void test_equal_int64(void);
+void test_not_equal_int64(void);
+void test_equal_uint64(void);
+void test_not_equal_uint64(void);
 
 static CutTest *test;
 static CutRunContext *run_context;
@@ -77,6 +81,11 @@ static gint fail_line;
 } while (0)
 
 #define FAIL_LOCATION (cut_take_printf("%s:%d", __FILE__, fail_line))
+#ifdef __clang__
+#  define FUNCTION(name) "void " name "()"
+#else
+#  define FUNCTION(name) name
+#endif
 
 static gboolean
 run (void)
@@ -195,11 +204,11 @@ test_equal_type (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "equal_type test",
                            NULL,
-                           "<G_TYPE_INT == G_TYPE_STRING>\n"
-                           "expected: <gint>\n"
-                           "  actual: <gchararray>",
+                           "<G_TYPE_INT == G_TYPE_STRING>",
+                           "gint", "gchararray",
                            FAIL_LOCATION,
-                           "stub_equal_type");
+                           FUNCTION("stub_equal_type"),
+                           NULL);
 }
 
 
@@ -228,11 +237,12 @@ test_equal_value (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "equal_value test",
                            NULL,
-                           "<value1 == value2>\n"
-                           "expected: <10> (gint)\n"
-                           "  actual: <\"String\"> (gchararray)",
+                           "<value1 == value2>",
+                           "10 (gint)",
+                           "\"String\" (gchararray)",
                            FAIL_LOCATION,
-                           "stub_equal_value");
+                           FUNCTION("stub_equal_value"),
+                           NULL);
 }
 
 static gboolean
@@ -282,17 +292,12 @@ test_equal_list (void)
         run_context, 0, CUT_TEST_RESULT_FAILURE,
         "equal_list test",
         NULL,
-        "<stub_equal_list_equal_func(list1[i], list2[i]) == TRUE>\n"
-        "expected: <(CCC: <100>, CCC: <-200>)>\n"
-        "  actual: <(CCC: <-1000>, CCC: <2000>)>\n"
-        "\n"
-        "diff:\n"
-        "- (CCC: <100>, CCC: <-200>)\n"
-        "?                    -\n"
-        "+ (CCC: <-1000>, CCC: <2000>)\n"
-        "?        + +            +",
+        "<stub_equal_list_equal_func(list1[i], list2[i]) == TRUE>",
+        "(CCC: <100>, CCC: <-200>)",
+        "(CCC: <-1000>, CCC: <2000>)",
         FAIL_LOCATION,
-        "stub_equal_list");
+        FUNCTION("stub_equal_list"),
+        NULL);
 }
 
 static void
@@ -320,17 +325,12 @@ test_equal_list_int (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "equal_list_int test",
                            NULL,
-                           "<list1 == list2>\n"
-                           "expected: <(100, -200)>\n"
-                           "  actual: <(-1000, 2000)>\n"
-                           "\n"
-                           "diff:\n"
-                           "- (100, -200)\n"
-                           "?      ^^\n"
-                           "+ (-1000, 2000)\n"
-                           "?  +   + ^   +",
+                           "<list1 == list2>",
+                           "(100, -200)",
+                           "(-1000, 2000)",
                            FAIL_LOCATION,
-                           "stub_equal_list_int");
+                           FUNCTION("stub_equal_list_int"),
+                           NULL);
 }
 
 static void
@@ -358,16 +358,12 @@ test_equal_list_uint (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "equal_list_uint test",
                            NULL,
-                           "<list1 == list2>\n"
-                           "expected: <(100, 200)>\n"
-                           "  actual: <(1000, 2000)>\n"
-                           "\n"
-                           "diff:\n"
-                           "- (100, 200)\n"
-                           "+ (1000, 2000)\n"
-                           "?     +     +",
+                           "<list1 == list2>",
+                           "(100, 200)",
+                           "(1000, 2000)",
                            FAIL_LOCATION,
-                           "stub_equal_list_uint");
+                           FUNCTION("stub_equal_list_uint"),
+                           NULL);
 }
 
 static void
@@ -397,11 +393,12 @@ test_equal_list_string (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "equal_list_string test",
                            NULL,
-                           "<list1 == list2>\n"
-                           "expected: <(\"abc\", \"def\")>\n"
-                           "  actual: <(\"zyx\", \"wvu\")>",
+                           "<list1 == list2>",
+                           "(\"abc\", \"def\")",
+                           "(\"zyx\", \"wvu\")",
                            FAIL_LOCATION,
-                           "stub_equal_list_string");
+                           FUNCTION("stub_equal_list_string"),
+                           NULL);
 }
 
 static void
@@ -463,11 +460,12 @@ test_equal_list_string_other_null (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "equal_list_string test (other NULL)",
                            NULL,
-                           "<list1 == list2>\n"
-                           "expected: <(\"abc\", \"abc\", \"def\")>\n"
-                           "  actual: <(NULL, \"abc\", \"def\")>",
+                           "<list1 == list2>",
+                           "(\"abc\", \"abc\", \"def\")",
+                           "(NULL, \"abc\", \"def\")",
                            FAIL_LOCATION,
-                           "stub_equal_list_string_other_null");
+                           FUNCTION("stub_equal_list_string_other_null"),
+                           NULL);
 }
 
 static void
@@ -495,8 +493,6 @@ test_equal_list_enum (void)
     const gchar inspected_actual[] =
         "(#<CutTestResultStatus: "
         "failure(CUT_TEST_RESULT_FAILURE:4)>)";
-        ;
-    const gchar *message, *message_with_diff;
 
     test = cut_test_new("equal_list_enum test", stub_equal_list_enum);
     cut_assert_not_null(test);
@@ -504,20 +500,14 @@ test_equal_list_enum (void)
     cut_assert_false(run());
     cut_assert_test_result_summary(run_context, 1, 2, 0, 1, 0, 0, 0, 0);
 
-    message = cut_take_printf("<list1 == list2>\n"
-                              "expected: <%s>\n"
-                              "  actual: <%s>",
-                              inspected_expected,
-                              inspected_actual);
-    message_with_diff = cut_append_diff(message,
-                                        inspected_expected,
-                                        inspected_actual);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "equal_list_enum test",
                            NULL,
-                           message_with_diff,
+                           "<list1 == list2>",
+                           inspected_expected, inspected_actual,
                            FAIL_LOCATION,
-                           "stub_equal_list_enum");
+                           FUNCTION("stub_equal_list_enum"),
+                           NULL);
 }
 
 static void
@@ -545,7 +535,6 @@ test_equal_list_flags (void)
         "third (CUTTEST_ASSERT_LIST_STUB_THIRD:0x4)>)";
     const gchar inspected_actual[] =
         "(#<CuttestAssertListStubFlags>)";
-    const gchar *message, *message_with_diff;
     static const GFlagsValue values[] = {
         {1 << 0, "CUTTEST_ASSERT_LIST_STUB_FIRST", "first"},
         {1 << 1, "CUTTEST_ASSERT_LIST_STUB_SECOND", "second"},
@@ -562,20 +551,14 @@ test_equal_list_flags (void)
     cut_assert_false(run());
     cut_assert_test_result_summary(run_context, 1, 2, 0, 1, 0, 0, 0, 0);
 
-    message = cut_take_printf("<list1 == list2>\n"
-                              "expected: <%s>\n"
-                              "  actual: <%s>",
-                              inspected_expected,
-                              inspected_actual);
-    message_with_diff = cut_append_diff(message,
-                                        inspected_expected,
-                                        inspected_actual);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "equal_list_flags test",
                            NULL,
-                           message_with_diff,
+                           "<list1 == list2>",
+                           inspected_expected, inspected_actual,
                            FAIL_LOCATION,
-                           "stub_equal_list_flags");
+                           FUNCTION("stub_equal_list_flags"),
+                           NULL);
 }
 
 static void
@@ -608,7 +591,6 @@ void
 test_equal_list_object (void)
 {
     const gchar *inspected_expected, *inspected_actual;
-    const gchar *message, *message_with_diff;
 
     test = cut_test_new("equal_list_object test",
                         stub_equal_list_object);
@@ -629,20 +611,15 @@ test_equal_list_object (void)
          "#<CutTest:%p name=<\"test2\">, element-name=<\"test\">, "
             "test-function=<NULL>, base-directory=<NULL>>)",
         list2->data, g_list_nth_data(list2, 2));
-    message = cut_take_printf("<list1 == list2>\n"
-                              "expected: <%s>\n"
-                              "  actual: <%s>",
-                              inspected_expected,
-                              inspected_actual);
-    message_with_diff = cut_append_diff(message,
-                                        inspected_expected,
-                                        inspected_actual);
+
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "equal_list_object test",
                            NULL,
-                           message_with_diff,
+                           "<list1 == list2>",
+                           inspected_expected, inspected_actual,
                            FAIL_LOCATION,
-                           "stub_equal_list_object");
+                           FUNCTION("stub_equal_list_object"),
+                           NULL);
 }
 
 static void
@@ -686,11 +663,12 @@ test_equal_hash_table (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "equal_hash_table test",
                            NULL,
-                           "<g_str_equal(hash1[key], hash2[key]) == TRUE>\n"
-                           "expected: <{1 => \"11\", 10 => \"22\"}>\n"
-                           "  actual: <{2 => \"99\", 20 => \"88\"}>",
+                           "<g_str_equal(hash1[key], hash2[key]) == TRUE>",
+                           "{1 => \"11\", 10 => \"22\"}",
+                           "{2 => \"99\", 20 => \"88\"}",
                            FAIL_LOCATION,
-                           "stub_equal_hash_table");
+                           FUNCTION("stub_equal_hash_table"),
+                           NULL);
 }
 
 static void
@@ -722,11 +700,12 @@ test_equal_hash_table_string_string (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "equal_hash_table_string_string test",
                            NULL,
-                           "<hash1 == hash2>\n"
-                           "expected: <{\"def\" => \"22\", \"abc\" => \"11\"}>\n"
-                           "  actual: <{\"wvu\" => \"88\", \"zyx\" => \"99\"}>",
+                           "<hash1 == hash2>",
+                           "{\"abc\" => \"11\", \"def\" => \"22\"}",
+                           "{\"wvu\" => \"88\", \"zyx\" => \"99\"}",
                            FAIL_LOCATION,
-                           "stub_equal_hash_table_string_string");
+                           FUNCTION("stub_equal_hash_table_string_string"),
+                           NULL);
 }
 
 static void
@@ -751,8 +730,10 @@ test_error (void)
                            NULL,
                            "expected: <error> is NULL\n"
                            "  actual: <g-file-error-quark:4: not found>",
+                           NULL, NULL,
                            FAIL_LOCATION,
-                           "stub_error");
+                           FUNCTION("stub_error"),
+                           NULL);
 }
 
 static void
@@ -778,17 +759,12 @@ test_equal_error (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "gcut_assert_equal_error test",
                            NULL,
-                           "<error1 == error2>\n"
-                           "expected: <g-file-error-quark:4: not found>\n"
-                           "  actual: <g-file-error-quark:4: no entry>\n"
-                           "\n"
-                           "diff:\n"
-                           "- g-file-error-quark:4: not found\n"
-                           "?                          ^^^^^^\n"
-                           "+ g-file-error-quark:4: no entry\n"
-                           "?                         +++ ^^",
+                           "<error1 == error2>",
+                           "g-file-error-quark:4: not found",
+                           "g-file-error-quark:4: no entry",
                            FAIL_LOCATION,
-                           "stub_equal_error");
+                           FUNCTION("stub_equal_error"),
+                           NULL);
 }
 
 static void
@@ -815,19 +791,12 @@ test_equal_enum (void)
         "gcut_assert_equal_enum test",
         NULL,
         "<CUT_TEST_RESULT_FAILURE == CUT_TEST_RESULT_PENDING>"
-        " (CUT_TYPE_TEST_RESULT_STATUS)\n"
-        "expected: <#<CutTestResultStatus: "
-        "failure(CUT_TEST_RESULT_FAILURE:4)>>\n"
-        "  actual: <#<CutTestResultStatus: "
-        "pending(CUT_TEST_RESULT_PENDING:3)>>\n"
-        "\n"
-        "diff:\n"
-        "- #<CutTestResultStatus: failure(CUT_TEST_RESULT_FAILURE:4)>\n"
-        "?                        ^^ ^^^^                 ^^ ^^^^ ^\n"
-        "+ #<CutTestResultStatus: pending(CUT_TEST_RESULT_PENDING:3)>\n"
-        "?                        ^^^^ ^^                 ^^^^ ^^ ^",
+        " (CUT_TYPE_TEST_RESULT_STATUS)",
+        "#<CutTestResultStatus: failure(CUT_TEST_RESULT_FAILURE:4)>",
+        "#<CutTestResultStatus: pending(CUT_TEST_RESULT_PENDING:3)>",
         FAIL_LOCATION,
-        "stub_equal_enum");
+        FUNCTION("stub_equal_enum"),
+        NULL);
 }
 
 static void
@@ -861,15 +830,15 @@ test_equal_flags (void)
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "gcut_assert_equal_flags test",
                            NULL,
-                           "<(1 << 1) | (1 << 2) == (1 << 3)> (flags_type)\n"
-                           "expected: <#<CuttestAssertStubFlags: "
+                           "<(1 << 1) | (1 << 2) == (1 << 3)> (flags_type)",
+                           "#<CuttestAssertStubFlags: "
                            "second|third "
                            "(CUTTEST_ASSERT_STUB_SECOND:0x2)|"
-                           "(CUTTEST_ASSERT_STUB_THIRD:0x4)>>\n"
-                           "  actual: <#<CuttestAssertStubFlags: "
-                           "(unknown flags: 0x8)>>",
+                           "(CUTTEST_ASSERT_STUB_THIRD:0x4)>",
+                           "#<CuttestAssertStubFlags: (unknown flags: 0x8)>",
                            FAIL_LOCATION,
-                           "stub_equal_flags");
+                           FUNCTION("stub_equal_flags"),
+                           NULL);
 }
 
 static void
@@ -888,7 +857,6 @@ void
 test_equal_object (void)
 {
     const gchar *inspected_expected, *inspected_actual;
-    const gchar *message;
 
     test = cut_test_new("gcut_assert_equal_object test", stub_equal_object);
     cut_assert_not_null(test);
@@ -904,17 +872,14 @@ test_equal_object (void)
                                        "so-filename=<\"so-name2\">, "
                                        "base-directory=<NULL>>",
                                        object2);
-    message = cut_take_printf("<object1 == object2>\n"
-                              "expected: <%s>\n"
-                              "  actual: <%s>",
-                              inspected_expected, inspected_actual);
-    message = cut_append_diff(message, inspected_expected, inspected_actual);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "gcut_assert_equal_object test",
                            NULL,
-                           message,
+                           "<object1 == object2>",
+                           inspected_expected, inspected_actual,
                            FAIL_LOCATION,
-                           "stub_equal_object");
+                           FUNCTION("stub_equal_object"),
+                           NULL);
 }
 
 static void
@@ -928,7 +893,6 @@ void
 test_equal_object_null (void)
 {
     const gchar *inspected_expected;
-    const gchar *message;
 
     test = cut_test_new("gcut_assert_equal_object_null test",
                         stub_equal_object_null);
@@ -941,16 +905,14 @@ test_equal_object_null (void)
                                          "so-filename=<\"so-name\">, "
                                          "base-directory=<NULL>>",
                                          object1);
-    message = cut_take_printf("<object1 == NULL>\n"
-                              "expected: <%s>\n"
-                              "  actual: <%s>",
-                              inspected_expected, "(null)");
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "gcut_assert_equal_object_null test",
                            NULL,
-                           message,
+                           "<object1 == NULL>",
+                           inspected_expected, "(null)",
                            FAIL_LOCATION,
-                           "stub_equal_object_null");
+                           FUNCTION("stub_equal_object_null"),
+                           NULL);
 }
 
 static gboolean
@@ -975,7 +937,6 @@ void
 test_equal_object_custom (void)
 {
     const gchar *inspected_expected, *inspected_actual;
-    const gchar *message;
 
     test = cut_test_new("gcut_assert_equal_object_custom test",
                         stub_equal_object_custom);
@@ -996,17 +957,14 @@ test_equal_object_custom (void)
                                        "test-function=<NULL>, "
                                        "base-directory=<NULL>>",
                                        object3);
-    message = cut_take_printf("<equal_name(object1, object3)>\n"
-                              "expected: <%s>\n"
-                              "  actual: <%s>",
-                              inspected_expected, inspected_actual);
-    message = cut_append_diff(message, inspected_expected, inspected_actual);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "gcut_assert_equal_object_custom test",
                            NULL,
-                           message,
+                           "<equal_name(object1, object3)>",
+                           inspected_expected, inspected_actual,
                            FAIL_LOCATION,
-                           "stub_equal_object_custom");
+                           FUNCTION("stub_equal_object_custom"),
+                           NULL);
 }
 
 static void
@@ -1024,11 +982,11 @@ test_equal_pid (void)
     cut_assert_test_result_summary(run_context, 1, 1, 0, 1, 0, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "cut_assert_equal_pid()", NULL,
-                           "<0 == (GPid)100>\n"
-                           "expected: <0>\n"
-                           "  actual: <100>",
+                           "<0 == (GPid)100>",
+                           "0", "100",
                            FAIL_LOCATION,
-                           "stub_equal_pid");
+                           FUNCTION("stub_equal_pid"),
+                           NULL);
 }
 
 static void
@@ -1046,13 +1004,105 @@ test_not_equal_pid (void)
     cut_assert_test_result_summary(run_context, 1, 1, 0, 1, 0, 0, 0, 0);
     cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
                            "cut_assert_not_equal_pid()", NULL,
-                           "<0 != 0>\n"
-                           "expected: <0>\n"
-                           "  actual: <0>",
+                           "<0 != 0>",
+                           "0", "0",
                            FAIL_LOCATION,
-                           "stub_not_equal_pid");
+                           FUNCTION("stub_not_equal_pid"),
+                           NULL);
 }
 
+static void
+stub_equal_int64 (void)
+{
+    gcut_assert_equal_int64(0, 0);
+    gcut_assert_equal_int64((gint64)G_MAXINT32 + 1, (gint64)G_MAXINT32 + 1);
+    MARK_FAIL(gcut_assert_equal_int64(G_MAXINT32, G_MAXINT64));
+}
+
+void
+test_equal_int64 (void)
+{
+    test = cut_test_new("cut_assert_equal_int64()", stub_equal_int64);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 1, 2, 0, 1, 0, 0, 0, 0);
+    cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
+                           "cut_assert_equal_int64()", NULL,
+                           "<G_MAXINT32 == G_MAXINT64>",
+                           "2147483647", "9223372036854775807",
+                           FAIL_LOCATION,
+                           FUNCTION("stub_equal_int64"),
+                           NULL);
+}
+
+static void
+stub_not_equal_int64 (void)
+{
+    gcut_assert_not_equal_int64(0, 1);
+    gcut_assert_not_equal_int64((gint64)G_MAXINT32, (gint64)G_MAXINT32 + 1);
+    MARK_FAIL(gcut_assert_not_equal_int64(G_MAXINT64, G_MAXINT64));
+}
+
+void
+test_not_equal_int64 (void)
+{
+    test = cut_test_new("cut_assert_not_equal_int64()", stub_not_equal_int64);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 1, 2, 0, 1, 0, 0, 0, 0);
+    cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
+                           "cut_assert_not_equal_int64()", NULL,
+                           "<G_MAXINT64 != G_MAXINT64>",
+                           "9223372036854775807", "9223372036854775807",
+                           FAIL_LOCATION,
+                           FUNCTION("stub_not_equal_int64"),
+                           NULL);
+}
+
+static void
+stub_equal_uint64 (void)
+{
+    gcut_assert_equal_uint64(0, 0);
+    gcut_assert_equal_uint64((guint64)G_MAXUINT32 + 1, (guint64)G_MAXUINT32 + 1);
+    MARK_FAIL(gcut_assert_equal_uint64(G_MAXUINT32, G_MAXUINT64));
+}
+
+void
+test_equal_uint64 (void)
+{
+    test = cut_test_new("cut_assert_equal_uint64()", stub_equal_uint64);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 1, 2, 0, 1, 0, 0, 0, 0);
+    cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
+                           "cut_assert_equal_uint64()", NULL,
+                           "<G_MAXUINT32 == G_MAXUINT64>",
+                           "4294967295", "18446744073709551615",
+                           FAIL_LOCATION,
+                           FUNCTION("stub_equal_uint64"),
+                           NULL);
+}
+
+static void
+stub_not_equal_uint64 (void)
+{
+    gcut_assert_not_equal_uint64(0, 1);
+    gcut_assert_not_equal_uint64((guint64)G_MAXUINT32,
+                                 (guint64)G_MAXUINT32 + 1);
+    MARK_FAIL(gcut_assert_not_equal_uint64(G_MAXUINT64, G_MAXUINT64));
+}
+
+void
+test_not_equal_uint64 (void)
+{
+    test = cut_test_new("cut_assert_not_equal_uint64()", stub_not_equal_uint64);
+    cut_assert_false(run());
+    cut_assert_test_result_summary(run_context, 1, 2, 0, 1, 0, 0, 0, 0);
+    cut_assert_test_result(run_context, 0, CUT_TEST_RESULT_FAILURE,
+                           "cut_assert_not_equal_uint64()", NULL,
+                           "<G_MAXUINT64 != G_MAXUINT64>",
+                           "18446744073709551615", "18446744073709551615",
+                           FAIL_LOCATION,
+                           FUNCTION("stub_not_equal_uint64"),
+                           NULL);
+}
 
 /*
 vi:nowrap:ai:expandtab:sw=4:ts=4
